install

Function install 

pub(crate) fn install(
    download_path: &Path,
    install_dir: &Path,
    installer_url: &str,
) -> Result<EngineInstallReceipt>
Extract an archive installer into the target install directory.

This preserves the packaged directory tree as-is and does not try to discover or promote a primary binary.